Crate macroforge_ts_quote

Crate macroforge_ts_quote 

Thin wrappers around SWC’s quote! machinery tailored for macroforge.

Macro authors can depend on this crate to access the familiar quote! macro (re-exported from swc_core) plus a couple of helpers for creating identifiers with predictable hygiene. The goal is to decouple codegen utilities from the heavier parsing utilities that live in ts_syn.

Macros

above
below
body
signature
ts_quote
ts_template
Template-style macro for TypeScript code generation.